@@ -1,14 +1,14 @@
-/* $Id: buffer.c,v 1.15 2001/11/05 15:23:05 rjkaes Exp $
+/* $Id: buffer.c,v 1.22 2002/05/24 04:45:32 rjkaes Exp $
  *
  * The buffer used in each connection is a linked list of lines. As the lines
  * are read in and written out the buffer expands and contracts. Basically,
- * by using this method we can increase the buffer size dynamicly. However,
+ * by using this method we can increase the buffer size dynamically. However,
  * we have a hard limit of 64 KB for the size of the buffer. The buffer can be
  * thought of as a queue were we act on both the head and tail. The various
  * functions act on each end (the names are taken from what Perl uses to act on
  * the ends of an array. :)
  *
- * Copyright (C) 1999  Robert James Kaes (rjkaes@flarenet.com)
+ * Copyright (C) 1999,2001  Robert James Kaes (rjkaes@users.sourceforge.net)
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -24,8 +24,8 @@
 #include "tinyproxy.h"
 
 #include "buffer.h"
+#include "heap.h"
 #include "log.h"
-#include "utils.h"
 
 #define BUFFER_HEAD(x) (x)->head
 #define BUFFER_TAIL(x) (x)->tail
@@ -33,17 +33,27 @@
 struct bufline_s {
 	unsigned char *string;	/* the actual string of data */
 	struct bufline_s *next;	/* pointer to next in linked list */
-	size_t length;	/* length of the string of data */
-	size_t pos;	/* start sending from this offset */
+	size_t length;		/* length of the string of data */
+	size_t pos;		/* start sending from this offset */
+};
+
+/*
+ * The buffer structure points to the beginning and end of the buffer list
+ * (and includes the total size)
+ */
+struct buffer_s {
+	struct bufline_s *head;	/* top of the buffer */
+	struct bufline_s *tail;	/* bottom of the buffer */
+	size_t size;		/* total size of the buffer */
 };
 
 /*
  * Take a string of data and a length and make a new line which can be added
- * to the buffer. We don't make a copy of the data, but simply copy the
- * pointer into the structure. In other words, when you insert data into the
- * buffer, the buffer becomes responsible for freeing it.
+ * to the buffer. The data IS copied, so make sure if you allocated your
+ * data buffer on the heap, delete it because you now have TWO copies.
  */
-static struct bufline_s *makenewline(unsigned char *data, size_t length)
+static struct bufline_s *
+makenewline(unsigned char *data, size_t length)
 {
 	struct bufline_s *newline;
 
@@ -53,7 +63,13 @@ static struct bufline_s *makenewline(unsigned char *data, size_t length)
 	if (!(newline = safemalloc(sizeof(struct bufline_s))))
 		return NULL;
 
-	newline->string = data;
+	if (!(newline->string = safemalloc(length))) {
+		safefree(newline);
+		return NULL;
+	}
+
+	memcpy(newline->string, data, length);
+
 	newline->next = NULL;
 	newline->length = length;
 
@@ -66,7 +82,8 @@ static struct bufline_s *makenewline(unsigned char *data, size_t length)
 /*
  * Free the allocated buffer line
  */
-static void free_line(struct bufline_s *line)
+static void
+free_line(struct bufline_s *line)
 {
 	assert(line != NULL);
 
@@ -82,7 +99,8 @@ static void free_line(struct bufline_s *line)
 /*
  * Create a new buffer
  */
-struct buffer_s *new_buffer(void)
+struct buffer_s *
+new_buffer(void)
 {
 	struct buffer_s *buffptr;
 
@@ -95,7 +113,7 @@ struct buffer_s *new_buffer(void)
 	 * moment.
 	 */
 	BUFFER_HEAD(buffptr) = BUFFER_TAIL(buffptr) = NULL;
-	BUFFER_SIZE(buffptr) = 0;
+	buffptr->size = 0;
 
 	return buffptr;
 }
@@ -103,7 +121,8 @@ struct buffer_s *new_buffer(void)
 /*
  * Delete all the lines in the buffer and the buffer itself
  */
-void delete_buffer(struct buffer_s *buffptr)
+void
+delete_buffer(struct buffer_s *buffptr)
 {
 	struct bufline_s *next;
 
@@ -119,10 +138,18 @@ void delete_buffer(struct buffer_s *buffptr)
 }
 
 /*
- * Push a new line on to the end of the buffer
+ * Return the current size of the buffer.
  */
-static int add_to_buffer(struct buffer_s *buffptr, unsigned char *data,
-			 size_t length)
+size_t buffer_size(struct buffer_s *buffptr)
+{
+	return buffptr->size;
+}
+
+/*
+ * Push a new line on to the end of the buffer.
+ */
+int
+add_to_buffer(struct buffer_s *buffptr, unsigned char *data, size_t length)
 {
 	struct bufline_s *newline;
 
@@ -135,9 +162,9 @@ static int add_to_buffer(struct buffer_s *buffptr, unsigned char *data,
 	 * have a size greater than zero, and vice-versa.
 	 */
 	if (BUFFER_HEAD(buffptr) == NULL)
-		assert(BUFFER_SIZE(buffptr) == 0);
+		assert(buffptr->size == 0);
 	else
-		assert(BUFFER_SIZE(buffptr) > 0);
+		assert(buffptr->size > 0);
 
 	/*
 	 * Make a new line so we can add it to the buffer.
@@ -145,12 +172,14 @@ static int add_to_buffer(struct buffer_s *buffptr, unsigned char *data,
 	if (!(newline = makenewline(data, length)))
 		return -1;
 
-	if (BUFFER_SIZE(buffptr) == 0)
+	if (buffptr->size == 0)
 		BUFFER_HEAD(buffptr) = BUFFER_TAIL(buffptr) = newline;
-	else
-		BUFFER_TAIL(buffptr) = (BUFFER_TAIL(buffptr)->next = newline);
+	else {
+		BUFFER_TAIL(buffptr)->next = newline;
+		BUFFER_TAIL(buffptr) = newline;
+	}
 
-	BUFFER_SIZE(buffptr) += length;
+	buffptr->size += length;
 
 	return 0;
 }
@@ -158,7 +187,8 @@ static int add_to_buffer(struct buffer_s *buffptr, unsigned char *data,
 /*
  * Remove the first line from the top of the buffer
  */
-static struct bufline_s *remove_from_buffer(struct buffer_s *buffptr)
+static struct bufline_s *
+remove_from_buffer(struct buffer_s *buffptr)
 {
 	struct bufline_s *line;
 
@@ -178,39 +208,32 @@ static struct bufline_s *remove_from_buffer(struct buffer_s *buffptr)
  * Takes a connection and returns the number of bytes read.
  */
 #define READ_BUFFER_SIZE (1024 * 2)
-ssize_t readbuff(int fd, struct buffer_s *buffptr)
+ssize_t
+read_buffer(int fd, struct buffer_s * buffptr)
 {
 	ssize_t bytesin;
-	unsigned char *buffer;
-	unsigned char *newbuffer;
+	unsigned char buffer[READ_BUFFER_SIZE];
 
 	assert(fd >= 0);
 	assert(buffptr != NULL);
 
-	if (BUFFER_SIZE(buffptr) >= READ_BUFFER_SIZE)
+	/*
+	 * Don't allow the buffer to grow larger than MAXBUFFSIZE
+	 */
+	if (buffptr->size >= MAXBUFFSIZE)
 		return 0;
 
-	buffer = safemalloc(READ_BUFFER_SIZE);
-	if (!buffer)
-		return 0;
-
-	bytesin = read(fd, buffer, READ_BUFFER_SIZE - BUFFER_SIZE(buffptr));
+	bytesin = read(fd, buffer, READ_BUFFER_SIZE);
 
 	if (bytesin > 0) {
-		newbuffer = saferealloc(buffer, bytesin);
-		if (!newbuffer) {
-			safefree(buffer);
-			return 0;
-		}
-
-		if (add_to_buffer(buffptr, newbuffer, bytesin) < 0) {
-			log_message(LOG_ERR, "readbuff: add_to_buffer() error.");
+		if (add_to_buffer(buffptr, buffer, bytesin) < 0) {
+			log_message(LOG_ERR,
+				    "readbuff: add_to_buffer() error.");
 			return -1;
 		}
 
 		return bytesin;
 	} else {
-		safefree(buffer);
 		if (bytesin == 0) {
 			/* connection was closed by client */
 			return -1;
@@ -226,7 +249,9 @@ ssize_t readbuff(int fd, struct buffer_s *buffptr)
 			case EINTR:
 				return 0;
 			default:
-				log_message(LOG_ERR, "readbuff: recv() error \"%s\" on file descriptor %d", strerror(errno), fd);
+				log_message(LOG_ERR,
+					    "readbuff: recv() error \"%s\" on file descriptor %d",
+					    strerror(errno), fd);
 				return -1;
 			}
 		}
@@ -237,7 +262,8 @@ ssize_t readbuff(int fd, struct buffer_s *buffptr)
  * Write the bytes in the buffer to the socket.
  * Takes a connection and returns the number of bytes written.
  */
-ssize_t writebuff(int fd, struct buffer_s *buffptr)
+ssize_t
+write_buffer(int fd, struct buffer_s * buffptr)
 {
 	ssize_t bytessent;
 	struct bufline_s *line;
@@ -245,14 +271,15 @@ ssize_t writebuff(int fd, struct buffer_s *buffptr)
 	assert(fd >= 0);
 	assert(buffptr != NULL);
 
-	if (BUFFER_SIZE(buffptr) == 0)
+	if (buffptr->size == 0)
 		return 0;
 
 	/* Sanity check. It would be bad to be using a NULL pointer! */
 	assert(BUFFER_HEAD(buffptr) != NULL);
-
 	line = BUFFER_HEAD(buffptr);
-	bytessent = write(fd, line->string + line->pos, line->length - line->pos);
+
+	bytessent =
+	    send(fd, line->string + line->pos, line->length - line->pos, MSG_NOSIGNAL);
 
 	if (bytessent >= 0) {
 		/* bytes sent, adjust buffer */
@@ -273,10 +300,14 @@ ssize_t writebuff(int fd, struct buffer_s *buffptr)
 			return 0;
 		case ENOBUFS:
 		case ENOMEM:
-			log_message(LOG_ERR, "writebuff: write() error [NOBUFS/NOMEM] \"%s\" on file descriptor %d", strerror(errno), fd);
+			log_message(LOG_ERR,
+				    "writebuff: write() error [NOBUFS/NOMEM] \"%s\" on file descriptor %d",
+				    strerror(errno), fd);
 			return 0;
 		default:
-			log_message(LOG_ERR, "writebuff: write() error \"%s\" on file descriptor %d", strerror(errno), fd);
+			log_message(LOG_ERR,
+				    "writebuff: write() error \"%s\" on file descriptor %d",
+				    strerror(errno), fd);
 			return -1;
 		}
 	}
