@@ -1,4 +1,4 @@
-/* $Id: buffer.h,v 1.5 2001/11/05 15:23:05 rjkaes Exp $
+/* $Id: buffer.h,v 1.8 2002/05/14 00:43:38 rjkaes Exp $
  *
  * See 'buffer.c' for a detailed description.
  *
@@ -18,25 +18,20 @@
 #ifndef _TINYPROXY_BUFFER_H_
 #define _TINYPROXY_BUFFER_H_
 
-/*
- * This structure contains the total size of a buffer, plus pointers to the
- * head and tail of the buffer.
- */
-struct buffer_s {
-	struct bufline_s *head;	/* top of the buffer */
-	struct bufline_s *tail;	/* bottom of the buffer */
-	size_t size;	/* total size of the buffer */
-};
-
-/*
- * Return the size of a buffer (pass a pointer to a buffer_s structure.)
- */
-#define BUFFER_SIZE(x) (x)->size
+/* Forward declaration */
+struct buffer_s;
 
 extern struct buffer_s *new_buffer(void);
 extern void delete_buffer(struct buffer_s *buffptr);
+extern size_t buffer_size(struct buffer_s *buffptr);
 
-extern ssize_t readbuff(int fd, struct buffer_s *buffptr);
-extern ssize_t writebuff(int fd, struct buffer_s *buffptr);
+/*
+ * Add a new line to the given buffer. The data IS copied into the structure.
+ */
+extern int add_to_buffer(struct buffer_s *buffptr, unsigned char *data,
+			 size_t length);
+
+extern ssize_t read_buffer(int fd, struct buffer_s *buffptr);
+extern ssize_t write_buffer(int fd, struct buffer_s *buffptr);
 
 #endif				/* __BUFFER_H_ */
