@@ -1,4 +1,4 @@
-/* $Id: filter.h,v 1.3 2000/11/23 04:46:25 rjkaes Exp $
+/* $Id: filter.h,v 1.5 2002/06/07 18:36:21 rjkaes Exp $
  *
  * See 'filter.c' for a detailed description.
  *
@@ -18,8 +18,16 @@
 #ifndef _TINYPROXY_FILTER_H_
 #define _TINYPROXY_FILTER_H_
 
+typedef enum {
+	FILTER_DEFAULT_ALLOW,
+	FILTER_DEFAULT_DENY,
+} filter_policy_t;
+
 extern void filter_init(void);
 extern void filter_destroy(void);
-extern int filter_url(char *host);
+extern int filter_domain(const char *host);
+extern int filter_url(const char *url);
+
+extern void filter_set_default_policy(filter_policy_t policy);
 
 #endif
