@@ -1,4 +1,4 @@
-/* $Id: utils.h,v 1.20 2002/06/15 17:28:19 rjkaes Exp $
+/* $Id: utils.h,v 1.23 2003/03/13 21:34:37 rjkaes Exp $
  *
  * See 'utils.h' for a detailed description.
  *
@@ -26,10 +26,8 @@ struct conn_s;
 
 extern int send_http_message(struct conn_s *connptr, int http_code,
 			     const char *error_title, const char *message);
-extern int send_http_error_message(struct conn_s *connptr);
-extern int indicate_http_error(struct conn_s* connptr, int number, const char *string);
 
-extern void pidfile_create(const char *path);
-extern int create_file_safely(const char *filename, bool_t truncate_file);
+extern int pidfile_create(const char *path);
+extern int create_file_safely(const char *filename, unsigned int truncate_file);
 
 #endif
